@@ -21,7 +21,6 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
-#include <sys/stat.h>
 #include <fcntl.h>
 #include <errno.h>
 #include <limits.h>
@@ -117,7 +116,7 @@ int get_partition_device_name(const char *device, char *out, int size)
 			p += 5;
 
 		snprintf(out, size, "/dev/%sp1", p);
-		if (stat(out, &st) == 0)
+		if (access(out, F_OK) == 0)
 			return 0;
 		if (stat(device, &st)) {
 			ploop_err(errno, "failed stat %s", device);
@@ -127,7 +126,10 @@ int get_partition_device_name(const char *device, char *out, int size)
 			ploop_err(errno, "failed mknod %s", out);
 			return -1;
 		}
-		chmod(device, 0600);
+		if (chmod(device, 0600)) {
+			ploop_err(errno, "failed chmod %s", device);
+			return -1;
+		}
 	} else
 		snprintf(out, size, "%s", device);
 
@@ -262,7 +264,12 @@ int resize_gpt_partition(const char *devname, __u64 new_size)
 		ploop_err(errno, "Failed to store secondary GPT header %s", devname);
 		goto err;
 	}
-	fsync(fd);
+	if (fsync(fd)) {
+		ploop_err(errno, "Can't fsync %s", devname);
+		ret = SYSEXIT_FSYNC;
+		goto err;
+	}
+
 	blkpg_resize_partition(fd, pe);
 	ret = 0;
 err:
