@@ -24,9 +24,8 @@
 #include <stdio.h>
 #include <time.h>
 
-#include "libploop.h"
+#include "ploop.h"
 
-#define LOG_BUF_SIZE	8192
 static int _s_log_enable = 1;
 static int _s_log_level = 3;
 static int _s_log_verbose_level = PLOOP_LOG_NOCONSOLE; // disable stdout/stderr
