@@ -233,12 +233,10 @@ int PREAD(struct delta * delta, void *buf, unsigned int size, off_t off)
 
 static int get_temp_mountpoint(const char *file, int create, char *buf, int len)
 {
-	struct stat st;
-
 	snprintf(buf, len, "%s.mnt", file);
 
 	if (create) {
-		if (stat(buf, &st) == 0)
+		if (access(buf, F_OK) == 0)
 			return 0;
 		if (mkdir(buf, 0700)) {
 			ploop_err(errno, "mkdir %s", buf);
@@ -260,7 +258,7 @@ static int is_fmt_version_valid(int version)
 
 static int default_fmt_version(void)
 {
-	return PLOOP_FMT_V1;
+	return ploop_is_large_disk_supported() ? PLOOP_FMT_V2 : PLOOP_FMT_V1;
 }
 
 static int check_size(unsigned long long sectors, __u32 blocksize, int version)
@@ -282,9 +280,12 @@ static int check_size(unsigned long long sectors, __u32 blocksize, int version)
 		return -1;
 	}
 
+	if (max > B2S(PLOOP_MAX_FS_SIZE))
+		max = B2S(PLOOP_MAX_FS_SIZE);
+
 	if (sectors > max) {
 		ploop_err(0, "An incorrect block device size is specified: %llu sectors."
-				" The maximum allowed size is %llu sectors.",
+				" The maximum allowed size is %llu sectors",
 				sectors, max);
 		return -1;
 	}
@@ -298,7 +299,7 @@ int check_blockdev_size(unsigned long long sectors, __u32 blocksize, int version
 
 	if (sectors % blocksize) {
 		ploop_err(0, "An incorrect block device size is specified: %llu sectors."
-				" The block device size must be aligned to the cluster block size %d.",
+				" The block device size must be aligned to the cluster block size %d",
 				sectors, blocksize);
 		return -1;
 	}
@@ -379,7 +380,7 @@ static int create_empty_preallocated_delta(const char *path, __u32 blocksize,
 	struct delta odelta = {};
 	int rc, clu, i;
 	void * buf = NULL;
-	struct ploop_pvd_header vh;
+	struct ploop_pvd_header vh = {};
 	__u32 SizeToFill;
 	__u32 l2_slot = 0;
 	off_t off;
@@ -402,8 +403,8 @@ static int create_empty_preallocated_delta(const char *path, __u32 blocksize,
 
 	memset(buf, 0, cluster);
 	SizeToFill = generate_pvd_header(&vh, bdsize, blocksize, version);
-	memcpy(buf, &vh, sizeof(struct ploop_pvd_header));
 	vh.m_Flags = CIF_Empty;
+	memcpy(buf, &vh, sizeof(struct ploop_pvd_header));
 
 	sizeBytes = S2B(vh.m_FirstBlockOffset + get_SizeInSectors(&vh));
 	rc = sys_fallocate(odelta.fd, 0, 0, sizeBytes);
@@ -536,7 +537,6 @@ static int create_image(struct ploop_disk_images_data *di,
 	struct ploop_pvd_header vh = {};
 	char fname[PATH_MAX];
 	char ddxml[PATH_MAX];
-	struct stat st;
 
 	if (size_sec == 0) {
 		ploop_err(0, "Incorrect block device size specified: "
@@ -548,13 +548,13 @@ static int create_image(struct ploop_disk_images_data *di,
 		return SYSEXIT_PARAM;
 	}
 
-	if (stat(file, &st) == 0) {
+	if (access(file, F_OK) == 0) {
 		ploop_err(EEXIST, "Can't create %s", file);
 		return SYSEXIT_PARAM;
 	}
 
 	get_disk_descriptor_fname_by_image(file, ddxml, sizeof(ddxml));
-	if (stat(ddxml, &st) == 0) {
+	if (access(ddxml, F_OK) == 0) {
 		ploop_err(EEXIST, "Can't create %s", ddxml);
 		return SYSEXIT_PARAM;
 	}
@@ -582,13 +582,11 @@ static int create_image(struct ploop_disk_images_data *di,
 	}
 
 	if (ploop_di_add_image(di, fname, TOPDELTA_UUID, NONE_UUID)) {
-		ret = SYSEXIT_NOMEM;
+		ret = SYSEXIT_MALLOC;
 		goto err;
 	}
 
-	if (ploop_store_diskdescriptor(ddxml, di))
-		goto err;
-	ret = 0;
+	ret = ploop_store_diskdescriptor(ddxml, di);
 err:
 	if (ret)
 		unlink(file);
@@ -728,7 +726,7 @@ int ploop_create_image(struct ploop_create_param *param)
 
 	di = alloc_diskdescriptor();
 	if (di == NULL)
-		return SYSEXIT_NOMEM;
+		return SYSEXIT_MALLOC;
 	di->blocksize = blocksize;
 	ret = create_image(di, param->image, di->blocksize,
 			round_bdsize(param->size, di->blocksize, version),
@@ -793,28 +791,48 @@ static int print_output(int level, const char *cmd, const char *arg)
 {
 	FILE *fp;
 	char command[PATH_MAX];
-	char buffer[8192]; /* same as LOG_BUF_SIZE */
+	char buffer[LOG_BUF_SIZE/2];
 	int ret = -1;
 	int eno = errno;
+	int i;
 
-	snprintf(command, sizeof(command), "%s %s", cmd, arg);
-
+	snprintf(command, sizeof(command), DEF_PATH_ENV " %s %s 2>&1",
+			cmd, arg);
 	if ((fp = popen(command, "r")) == NULL) {
-		ploop_err(errno, "Can't exec %s", command);
+		ploop_err(errno, "Can't exec %s %s", cmd, arg);
 		goto out;
 	}
 
+	ploop_log(level, "--- %s %s output ---", cmd, arg);
 	while (fgets(buffer, sizeof(buffer), fp)) {
 		char *p = strrchr(buffer, '\n');
 		if (p != NULL)
 			*p = '\0';
-		ploop_log(level, "--- %s output follows ---\n%s",
-				command, buffer);
+		ploop_log(level, "%s", buffer);
 	}
-	pclose(fp);
-	ploop_log(level, "--- %s finished ---", cmd);
 
-	ret = 0;
+	i = pclose(fp);
+	if (i == -1) {
+		ploop_err(errno, "Error in pclose() for %s", cmd);
+		goto out;
+	} else if (WIFEXITED(i)) {
+		ret = WEXITSTATUS(i);
+		switch (ret) {
+			case 0:
+				ploop_log(level, "--- %s finished ---", cmd);
+				break;
+			case 127: /* "command not found" from shell */
+				/* error is printed by shell*/
+				break;
+			default:
+				ploop_err(0, "Command %s exited with "
+						"status %d", cmd, ret);
+		}
+	} else if (WIFSIGNALED(i)) {
+		ploop_err(0, "Command %s received signal %d",
+				cmd, WTERMSIG(i));
+	} else
+		ploop_err(0, "Command %s died", cmd);
 
 out:
 	errno = eno;
@@ -823,20 +841,32 @@ out:
 
 static int do_umount(const char *mnt)
 {
-	int i, ret;
+	int i = 0;
+	int ret = 0;
+
+retry:
+	if (umount(mnt) == 0)
+		return 0;
+
+	if (errno != EBUSY)
+		goto err;
+
+	if (i++ < 6) {
+		if (ploop_get_log_level() >= 3 && ret != 127)
+			ret = print_output(3, "lsof", mnt);
 
-	for (i = 0; i < 6; i++) {
-		ret = umount(mnt);
-		if (ret == 0 || (ret == -1 && errno != EBUSY))
-			return ret;
-		if (ploop_get_log_level() > 3)
-			print_output(3, "lsof", mnt);
-		ploop_log(3, "Retrying umount %s", mnt);
 		sleep(1);
+		ploop_log(3, "Retrying umount %s", mnt);
+		goto retry;
 	}
-	print_output(-1, "lsof", mnt);
-	ploop_err(-1, "Can't umount %s", mnt);
-	return -1;
+
+	if (ret != 127)
+		print_output(-1, "lsof", mnt);
+
+err:
+	ploop_err(errno, "Failed to umount %s", mnt);
+
+	return SYSEXIT_UMOUNT;
 }
 
 static int delete_deltas(int devfd, const char *devname)
@@ -1172,25 +1202,30 @@ static int create_ploop_dev(int minor)
 {
 	char device[64];
 	char devicep1[64];
-	struct stat st;
 
 	strcpy(device, "/dev/");
 	make_sysfs_dev_name(minor, device + 5, sizeof(device) - 5);
 	/* Create pair /dev/ploopN & /dev/ploopNp1 */
-	if (stat(device, &st)) {
+	if (access(device, F_OK)) {
 		if (mknod(device, S_IFBLK, gnu_dev_makedev(PLOOP_DEV_MAJOR, minor))) {
 			ploop_err(errno, "mknod %s", device);
 			return SYSEXIT_MKNOD;
 		}
-		chmod(device, 0600);
+		if (chmod(device, 0600)) {
+			ploop_err(errno, "chmod %s", device);
+			return SYSEXIT_SYS;
+		}
 	}
 	snprintf(devicep1, sizeof(devicep1), "%sp1", device);
-	if (stat(devicep1, &st)) {
+	if (access(devicep1, F_OK)) {
 		if (mknod(devicep1, S_IFBLK, gnu_dev_makedev(PLOOP_DEV_MAJOR, minor+1))) {
 			ploop_err(errno, "mknod %s", devicep1);
 			return SYSEXIT_MKNOD;
 		}
-		chmod(devicep1, 0600);
+		if (chmod(devicep1, 0600)) {
+			ploop_err(errno, "chmod %s", devicep1);
+			return SYSEXIT_SYS;
+		}
 	}
 	return 0;
 }
@@ -1285,9 +1320,6 @@ err:
 	return ret;
 }
 
-#ifndef EXT4_SUPER_MAGIC
-#define EXT4_SUPER_MAGIC	0xEF53
-#endif
 #ifndef FS_IOC_GETFLAGS
 #define FS_IOC_GETFLAGS	_IOR('f', 1, long)
 #endif
@@ -1323,7 +1355,7 @@ static int check_mount_restrictions(struct ploop_mount_param *param, const char
 
 		if (!(flags & EXT4_EXTENTS_FL)) {
 			ploop_err(0, "The ploop image can not be used on ext3 or ext4 file"
-					" system without extents.");
+					" system without extents");
 			return 1;
 		}
 	}
@@ -1336,7 +1368,6 @@ int ploop_mount(struct ploop_disk_images_data *di, char **images,
 {
 	int lfd = -1;
 	struct stat st;
-	int i;
 	int ret = 0;
 	__u32 blocksize = 0;
 
@@ -1347,7 +1378,7 @@ int ploop_mount(struct ploop_disk_images_data *di, char **images,
 
 	if (param->target != NULL) {
 		if (stat(param->target, &st)) {
-			ploop_err(0, "Mount point %s does not exist", param->target);
+			ploop_err(errno, "Failed to stat mount point %s", param->target);
 			return SYSEXIT_PARAM;
 		}
 		if (!S_ISDIR(st.st_mode)) {
@@ -1374,30 +1405,9 @@ int ploop_mount(struct ploop_disk_images_data *di, char **images,
 	if (di && (ret = check_and_restore_fmt_version(di)))
 		goto err;
 
-	for (i = 0; images[i] != NULL; i++) {
-		int ro;
-		int flags = CHECK_DETAILED | (di ? CHECK_DROPINUSE : 0);
-		__u32 cur_blocksize;
-
-		if (raw && i == 0)
-			continue;
-
-		ro  = (images[i+1] != NULL || param->ro) ? 1 : 0;
-		ret = ploop_check(images[i], flags, ro, 0, &cur_blocksize);
-		if (ret) {
-			ploop_err(0, "%s (%s): irrecoverable errors",
-					images[i], ro ? "ro" : "rw");
-			goto err;
-		}
-		if (blocksize == 0)
-			blocksize = cur_blocksize;
-		if (cur_blocksize != blocksize) {
-			ploop_err(0, "Incorrect blocksize %s bs=%d [current bs=%d]",
-					images[i], blocksize, cur_blocksize);
-			ret = SYSEXIT_PARAM;
-			goto err;
-		}
-	}
+	ret = check_deltas(di, images, param, raw, &blocksize);
+	if (ret)
+		goto err;
 
 	ret = add_deltas(di, images, param, raw, blocksize, &lfd);
 	if (ret)
@@ -1451,7 +1461,7 @@ static int mount_image(struct ploop_disk_images_data *di, struct ploop_mount_par
 
 	images = make_images_list(di, guid, 0);
 	if (images == NULL)
-		return SYSEXIT_NOMEM;
+		return SYSEXIT_MALLOC;
 
 	ret = ploop_mount(di, images, param, (di->mode == PLOOP_RAW_MODE));
 
@@ -1545,10 +1555,9 @@ int ploop_umount(const char *device, struct ploop_disk_images_data *di)
 		if (di != NULL && di->runtime->component_name == NULL)
 			store_statfs_info(mnt, di->images[0]->file);
 		ploop_log(0, "Unmounting file system at %s", mnt);
-		if (do_umount(mnt)) {
-			ploop_err(errno, "umount %s failed", mnt);
-			return SYSEXIT_UMOUNT;
-		}
+		ret = do_umount(mnt);
+		if (ret)
+			return ret;
 	}
 
 	ret = ploop_stop_device(device);
@@ -1593,6 +1602,89 @@ int ploop_umount_image(struct ploop_disk_images_data *di)
 	return ret;
 }
 
+static int get_image_param_online(const char *device, off_t *size,
+		__u32 *blocksize, int *version)
+{
+	if (ploop_get_attr(device, "block_size",  (int *)blocksize))
+		return SYSEXIT_SYSFS;
+
+	*version = PLOOP_FMT_V1;
+	if (ploop_is_large_disk_supported() &&
+			ploop_get_attr(device, "fmt_version", version))
+		return SYSEXIT_SYSFS;
+
+	return ploop_get_size(device, size);
+}
+
+static int get_image_param_offline(struct ploop_disk_images_data *di, const char *guid,
+		off_t *size, __u32 *blocksize, int *version)
+{
+	int ret;
+	struct delta delta;
+	const char *image;
+	int raw = 0;
+
+	image = find_image_by_guid(di, guid);
+	if (image == NULL) {
+		ploop_err(0, "Can't find image by top guid %s",
+				guid);
+		return SYSEXIT_PARAM;
+	}
+	if (di->mode == PLOOP_RAW_MODE) {
+		int i;
+
+		i = find_snapshot_by_guid(di, guid);
+		if (i == -1) {
+			ploop_err(0, "Can't find snapshot by guid %s",
+					guid);
+			return SYSEXIT_PARAM;
+		}
+		if (strcmp(di->snapshots[i]->parent_guid, NONE_UUID) == 0)
+			raw = 1;
+	}
+	if (raw) {
+		struct stat st;
+
+		if (stat(image, &st)) {
+			ploop_err(errno, "Failed to stat %s",
+					image);
+			return SYSEXIT_FSTAT;
+		}
+		*size = st.st_size / SECTOR_SIZE;
+		*version = PLOOP_FMT_UNDEFINED;
+		*blocksize = di->blocksize;
+	} else {
+		ret = open_delta(&delta, image, O_RDONLY, OD_OFFLINE);
+		if (ret)
+			return ret;
+		*size = delta.l2_size * delta.blocksize;
+		*version = delta.version;
+		*blocksize = delta.blocksize;
+		close_delta(&delta);
+	}
+
+	return 0;
+}
+
+static int get_image_param(struct ploop_disk_images_data *di, const char *guid,
+		off_t *size, __u32 *blocksize, int *version)
+{
+	int ret;
+	char dev[64];
+
+	/* The 'size' parameter is delta specific so
+	 * get offline for non top delta.
+	 */
+	if (strcmp(di->top_guid, guid) == 0) {
+		ret = ploop_find_dev_by_uuid(di, 1, dev, sizeof(dev));
+		if (ret == -1)
+			return SYSEXIT_SYS;
+		if (ret == 0)
+			return get_image_param_online(dev, size, blocksize, version);
+	}
+	return get_image_param_offline(di, guid, size, blocksize, version);
+}
+
 int ploop_grow_device(const char *device, off_t new_size)
 {
 	int fd, ret;
@@ -1606,11 +1698,11 @@ int ploop_grow_device(const char *device, off_t new_size)
 		return ret;
 
 	if (ploop_get_attr(device, "block_size", (int*) &blocksize))
-		return SYSEXIT_SYS;
+		return SYSEXIT_SYSFS;
 
 	if (ploop_is_large_disk_supported() &&
 			ploop_get_attr(device, "fmt_version", &version))
-		return SYSEXIT_SYS;
+		return SYSEXIT_SYSFS;
 
 	if (new_size == size)
 		return 0;
@@ -1681,7 +1773,7 @@ int ploop_grow_image(struct ploop_disk_images_data *di, off_t size)
 		}
 
 		fname = find_image_by_guid(di, di->top_guid);
-		if (i == -1) {
+		if (!fname) {
 			ploop_err(0, "Unable to find top delta file name");
 			ret = SYSEXIT_PARAM;
 			goto err;
@@ -1733,7 +1825,7 @@ static int ploop_raw_discard(struct ploop_disk_images_data *di, const char *devi
 	get_disk_descriptor_fname(di, conf, sizeof(conf));
 	ret = ploop_store_diskdescriptor(conf, di);
 	if (ret)
-		return SYSEXIT_DISKDESCR;
+		return ret;
 
 	return 0;
 }
@@ -1846,18 +1938,16 @@ int ploop_resize_image(struct ploop_disk_images_data *di, struct ploop_resize_pa
 		mounted = 1;
 	}
 
-	/* FIXME: Deny resize image if there are children */
-	ret = SYSEXIT_SYSFS;
-	if (ploop_get_attr(mount_param.device, "block_size", (int *)&blocksize))
+	//FIXME: Deny resize image if there are childs
+	ret = get_image_param_online(mount_param.device, &dev_size,
+			&blocksize, &version);
+	if (ret)
 		goto err;
 
-	version = PLOOP_FMT_V1;
-	if (ploop_is_large_disk_supported() &&
-			ploop_get_attr(mount_param.device, "fmt_version", &version))
-		goto err;
-
-	if (check_size(param->size, blocksize, version))
+	if (check_size(param->size, blocksize, version)) {
+		ret = SYSEXIT_PARAM;
 		goto err;
+	}
 
 	new_size = round_bdsize(param->size, blocksize, version);
 
@@ -1867,9 +1957,6 @@ int ploop_resize_image(struct ploop_disk_images_data *di, struct ploop_resize_pa
 		goto err;
 	}
 
-	ret = ploop_get_size(mount_param.device, &dev_size);
-	if (ret)
-		goto err;
 	ret = ploop_get_size(part_device, &part_dev_size);
 	if (ret)
 		goto err;
@@ -1923,13 +2010,12 @@ int ploop_resize_image(struct ploop_disk_images_data *di, struct ploop_resize_pa
 		balloonfd = -1;
 		if (!mounted && param->offline_resize) {
 			/* offline */
-			if (do_umount(mount_param.target)) {
-				ploop_err(errno, "umount %s failed", mount_param.target);
-			} else {
-				ret = e2fsck(part_device, E2FSCK_FORCE | E2FSCK_PREEN);
-				if (ret)
-					goto err;
-			}
+			ret = do_umount(mount_param.target);
+			if (ret)
+				goto err;
+			ret = e2fsck(part_device, E2FSCK_FORCE | E2FSCK_PREEN);
+			if (ret)
+				goto err;
 		}
 
 		// Update size in the DiskDescriptor.xml
@@ -1975,11 +2061,8 @@ int ploop_resize_image(struct ploop_disk_images_data *di, struct ploop_resize_pa
 			balloonfd = -1;
 
 			ret = do_umount(mount_param.target);
-			if (ret) {
-				ploop_err(errno, "umount %s failed", mount_param.target);
-				ret = SYSEXIT_UMOUNT;
+			if (ret)
 				goto err;
-			}
 
 			ret = shrink_device(di, mount_param.device, part_device, part_dev_size,
 					new_fs_size, blocksize);
@@ -2329,7 +2412,7 @@ static int change_fmt_version(struct delta *d, int new_version)
 
 		off = ploop_ioff_to_sec(d->l2[l2_slot], d->blocksize, d->version);
 		if (new_version == PLOOP_FMT_V1 && check_size(off, d->blocksize, new_version)) {
-			ret = SYSEXIT_PLOOPFMT;
+			ret = SYSEXIT_PARAM;
 			goto err;
 		}
 		d->l2[l2_slot] = ploop_sec_to_ioff(off, d->blocksize, new_version);
@@ -2601,7 +2684,7 @@ int check_and_restore_fmt_version(struct ploop_disk_images_data *di)
 
 	close_delta(&d);
 
-	ploop_log(0, "Image remains in converting fmt version state, restore...");
+	ploop_log(0, "Image remains in converting fmt version state, restoring...");
 	for (i = 0; i < di->nimages; i++) {
 		if (i == base_id)
 			continue;
@@ -2691,7 +2774,7 @@ int create_snapshot(const char *device, const char *delta, int syncfs)
 	int ret;
 	int lfd = -1;
 	int fd = -1;
-	__u64 bdsize;
+	off_t bdsize;
 	struct ploop_ctl_delta req;
 	__u32 blocksize;
 	int version;
@@ -2700,13 +2783,10 @@ int create_snapshot(const char *device, const char *delta, int syncfs)
 	if (ret)
 		return ret;
 
-	if (ploop_get_attr(device, "block_size", (int*) &blocksize))
-		return SYSEXIT_SYSFS;
-
-	version = PLOOP_FMT_V1;
-	if (ploop_is_large_disk_supported() &&
-			ploop_get_attr(device, "fmt_version", &version))
-		return SYSEXIT_SYSFS;
+	ret = get_image_param_online(device, &bdsize,
+			&blocksize, &version);
+	if (ret)
+		return ret;
 
 	lfd = open(device, O_RDONLY);
 	if (lfd < 0) {
@@ -2714,19 +2794,6 @@ int create_snapshot(const char *device, const char *delta, int syncfs)
 		return SYSEXIT_DEVICE;
 	}
 
-	if (ioctl(lfd, BLKGETSIZE64, &bdsize) < 0) {
-		ploop_err(errno, "ioctl(BLKGETSIZE) %s", device);
-		ret = SYSEXIT_BLKDEV;
-		goto err;
-	}
-	bdsize = bytes2sec(bdsize);
-
-	if (bdsize == 0) {
-		ploop_err(0, "Can't get block device %s size", device);
-		ret = SYSEXIT_BLKDEV;
-		goto err;
-	}
-
 	fd = create_empty_delta(delta, blocksize, bdsize, version);
 	if (fd < 0) {
 		ret = SYSEXIT_OPEN;
@@ -2755,56 +2822,6 @@ err:
 	return ret;
 }
 
-static int get_image_param(struct ploop_disk_images_data *di, const char *guid,
-		off_t *size, __u32 *blocksize, int *version)
-{
-	int ret;
-	struct delta delta;
-	const char *image;
-	int raw = 0;
-
-	image = find_image_by_guid(di, guid);
-	if (image == NULL) {
-		ploop_err(0, "Can't find image by top guid %s",
-				guid);
-		return SYSEXIT_PARAM;
-	}
-	if (di->mode == PLOOP_RAW_MODE) {
-		int i;
-
-		i = find_snapshot_by_guid(di, guid);
-		if (i == -1) {
-			ploop_err(0, "Can't find snapshot by guid %s",
-					guid);
-			return SYSEXIT_PARAM;
-		}
-		if (strcmp(di->snapshots[i]->parent_guid, NONE_UUID) == 0)
-			raw = 1;
-	}
-	if (raw) {
-		struct stat st;
-
-		if (stat(image, &st)) {
-			ploop_err(errno, "Failed to stat %s",
-					image);
-			return SYSEXIT_FSTAT;
-		}
-		*size = st.st_size / SECTOR_SIZE;
-		*version = PLOOP_FMT_UNDEFINED;
-		*blocksize = di->blocksize;
-	} else {
-		ret = open_delta(&delta, image, O_RDONLY, OD_OFFLINE);
-		if (ret)
-			return ret;
-		*size = delta.l2_size * delta.blocksize;
-		*version = delta.version;
-		*blocksize = delta.blocksize;
-		close_delta(&delta);
-	}
-
-	return 0;
-}
-
 int ploop_get_spec(struct ploop_disk_images_data *di, struct ploop_spec *spec)
 {
 	int ret;
@@ -2874,7 +2891,7 @@ int ploop_create_snapshot(struct ploop_disk_images_data *di, struct ploop_snapsh
 		 */
 		ret = SYSEXIT_PARAM;
 		ploop_err(errno, "Unable to create a snapshot."
-			" The maximum number of snapshots (%d) has been reached.",
+			" The maximum number of snapshots (%d) has been reached",
 			n-1);
 		goto err_cleanup1;
 	}
@@ -2902,7 +2919,7 @@ int ploop_create_snapshot(struct ploop_disk_images_data *di, struct ploop_snapsh
 
 	if (!online) {
 		// offline snapshot
-		ret = get_image_param(di, snap_guid, &size, &blocksize, &version);
+		ret = get_image_param_offline(di, snap_guid, &size, &blocksize, &version);
 		if (ret)
 			goto err_cleanup2;
 
