@@ -4,12 +4,14 @@
 #include <linux/types.h>
 #include <string.h>
 #include <sys/stat.h>
+#include <sys/syscall.h>
 #include <assert.h>
 
 #include "ploop_if.h"
 #include "ploop1_image.h"
 #include "libploop.h"
 
+#define PLOOP_MAX_FS_SIZE	16ULL*1024*1024*1024*1024
 #define PLOOP_DEV_MAJOR 182
 
 #ifndef __NR_fallocate
@@ -32,6 +34,11 @@
 #endif
 #endif /* ! __NR_syncfs */
 
+/* from linux/magic.h */
+#ifndef EXT4_SUPER_MAGIC
+#define EXT4_SUPER_MAGIC	0xEF53
+#endif
+
 #define DISKDESCRIPTOR_XML	"DiskDescriptor.xml"
 /* Compatibility: Parallels use this UUID to mark top delta */
 #define TOPDELTA_UUID		"{5fbaabe3-6958-40ff-92a7-860e329aab41}"
@@ -49,6 +56,7 @@
 #define CHECK_HARDFORCE	0x02
 #define CHECK_DROPINUSE	0x04
 #define CHECK_DETAILED	0x08
+#define CHECK_REPAIR_SPARSE	0x10
 
 /* GPT */
 #define GPT_HEADER_SIZE		1
@@ -60,6 +68,12 @@
 #define ROUNDUP(size, blocksize) \
 	(((off_t)size + blocksize - 1) / blocksize * blocksize)
 
+/* PATH used by the library */
+#define DEF_PATH_ENV	"PATH=/sbin:/bin:/usr/sbin:/usr/bin:" \
+			"/usr/local/sbin:/usr/local/bin"
+#define DEF_PATH_LIST	{ "/sbin", "/bin", "/usr/sbin", "/usr/bin", \
+			"/usr/local/sbin", "/usr/bin", NULL }
+
 struct delta_fops
 {
 	int		(*open)(char *pathname, int flags, mode_t mode);
@@ -205,7 +219,7 @@ static inline off_t ploop_ioff_to_sec(__u32 iblk, __u32 blocksize, int version)
 	case PLOOP_FMT_V1:
 		return iblk;
 	case PLOOP_FMT_V2:
-		return iblk * blocksize;
+		return (off_t)iblk * blocksize;
 	default:
 		assert(0);
 	}
@@ -222,7 +236,7 @@ int get_dev_by_name(const char *name, dev_t *dev);
 int get_dev_start(const char *path, __u32 *start);
 int ploop_get_top_level(int devfd, const char *devname, int *top);
 
-int init_delta_array(struct delta_array *);
+void init_delta_array(struct delta_array *);
 void deinit_delta_array(struct delta_array * p);
 int extend_delta_array(struct delta_array * p, char * path, int rw, int od_flags);
 void close_delta(struct delta *delta);
@@ -267,8 +281,13 @@ struct relocmap *relocmap_alloc(int n);
 struct ploop_relocblks_ctl;
 int relocmap2relocblks(struct relocmap *relocmap, int lvl, __u32 a_h, __u32 n_scanned,
 			struct ploop_relocblks_ctl **relocblks_pp);
-PL_EXT int ploop_check(char *img, int flags, int ro, int verbose, __u32 *blocksize_p);
+PL_EXT int ploop_check(char *img, int flags, int ro, int raw, int verbose,
+		__u32 *blocksize_p);
+int check_deltas(struct ploop_disk_images_data *di, char **images,
+                struct ploop_mount_param *param, int raw, __u32 *blocksize);
+int ploop_check_delta(const char *image, int fd, __u64 blocksize);
 /* Logging */
+#define LOG_BUF_SIZE	8192
 int ploop_get_log_level(void);
 void ploop_log(int level, const char *format, ...)
 	__attribute__ ((__format__ (__printf__, 2, 3)));
