@@ -192,7 +192,7 @@ int ploop_set_component_name(struct ploop_disk_images_data *di,
 	free(di->runtime->component_name);
 	di->runtime->component_name = strdup(component_name);
 	if (di->runtime->component_name == NULL)
-		return SYSEXIT_NOMEM;
+		return SYSEXIT_MALLOC;
 	return 0;
 }
 
@@ -220,12 +220,7 @@ static void cleanup_kill_process(void *data)
 
 static int ploop_execvp(const char *file, char *const argv[])
 {
-	char *const paths[] = {
-		"/sbin", "/bin",
-		"/usr/sbin", "/usr/bin",
-		"/usr/local/sbin", "/usr/bin",
-		NULL
-	};
+	char *const paths[] = DEF_PATH_LIST;
 	int i, ret;
 
 	if (file[0] == '/')
