@@ -29,43 +29,57 @@
 #include <signal.h>
 #include <sys/types.h>
 #include <dirent.h>
+#include <ctype.h>
 
 #include "ploop.h"
 #include "common.h"
 
 extern int plooptool_snapshot_list(int argc, char **argv);
+extern int plooptool_check(int argc, char **argv);
+extern int plooptool_grow(int argc, char **argv);
+extern int plooptool_merge(int argc, char ** argv);
+extern int plooptool_stat(int argc, char ** argv);
+extern int plooptool_copy(int argc, char ** argv);
+
+#define USAGE_FORMATS	"{ raw | ploop1 | expanded | preallocated }"
+#define USAGE_VERSIONS	"{ 1 | 2 } (default 2, if supported)"
 
 static void usage_summary(void)
 {
 	fprintf(stderr, "Usage: ploop init -s SIZE [-f FORMAT] NEW_DELTA\n"
-			"       ploop mount [-r] [-f raw] [-d DEVICE] BASE_DELTA [ ... TOP_DELTA]\n"
-			"       ploop umount -d DEVICE\n"
-			"       ploop { delete | rm } -d DEVICE -l LEVEL\n"
-			"       ploop merge -d DEVICE [-l LEVEL[..TOP_LEVEL]]\n"
-			"       ploop check [-fcr] DELTA\n"
-			"       ploop getdev\n"
-			"       ploop resize -s SIZE BASE_DELTA\n"
-			"       ploop snapshot [-F] -d DEVICE NEW_DELTA\n"
+			"       ploop mount [-r] [-m DIR] DiskDescriptor.xml\n"
+			"       ploop umount { -d DEVICE | -m DIR | DELTA | DiskDescriptor.xml }\n"
+			"       ploop check [-fFcrsdS] [-R -b BLOCKSIZE] { DELTA | DiskDescriptor.xml }\n"
+			"       ploop convert [-f FORMAT] [-v VERSION] DiskDescriptor.xml\n"
+			"       ploop resize -s SIZE DiskDescriptor.xml\n"
+			"       ploop balloon { show | status | clear | change | complete | check |\n"
+			"                       repair | discard } ... DiskDescriptor.xml\n"
 			"       ploop snapshot DiskDescriptor.xml\n"
 			"       ploop snapshot-delete -u <uuid> DiskDescriptor.xml\n"
 			"       ploop snapshot-merge [-u <uuid>] DiskDescriptor.xml\n"
 			"       ploop snapshot-switch -u <uuid> DiskDescriptor.xml\n"
-			"       ploop snapshot-list [-o field[,field...]] [--uuid <UUID>] DiskDescriptor.xml\n"
-			"Also:  ploop { stat | start | stop | clear } ...\n"
+			"       ploop snapshot-list [-o field[,field...]] [-u <UUID>] DiskDescriptor.xml\n"
+			"Also:  ploop { start | stop | delete | clear | merge | grow | copy |\n"
+			"               stat | info | list} ...\n"
+			"\n"
+			"       ploop <command> -- to get detailed syntax for a specific command\n"
 		);
 }
 
 static void usage_init(void)
 {
-	fprintf(stderr, "Usage: ploop init -s SIZE [-f FORMAT] [-v VERSION] [-t FSTYPE] [-b BLOCKSIZE]\n"
-			"		[-B FSBLOCKSIZE] DELTA\n"
-			"       SIZE := NUMBER[KMGT]\n"
-			"       FORMAT := { raw | ploop1 }\n"
-			"       VERSION := { 1 | 2 }\n"
-			"       DELTA := path to new image file\n"
-			"       FSTYPE := make file system\n"
-			"       BLOCKSIZE := cluster block size in sectors\n"
-			"       FSBLOCKSIZE := file system block size in bytes\n");
+	fprintf(stderr,
+"Usage: ploop init -s SIZE [-f FORMAT] [-v VERSION] [-t FSTYPE]\n"
+"                 [-b BLOCKSIZE] [-B FSBLOCKSIZE] DELTA\n"
+"\n"
+"       SIZE        := NUMBER[KMGT]\n"
+"       FORMAT      := " USAGE_FORMATS "\n"
+"       VERSION     := " USAGE_VERSIONS "\n"
+"       FSTYPE      := { none | ext3 | ext4 } (create filesystem, default ext4)\n"
+"       BLOCKSIZE   := cluster block size, sectors\n"
+"       FSBLOCKSIZE := file system block size, bytes\n"
+"       DELTA       := path to a new image file\n"
+	);
 }
 
 static int parse_version_opt(const char *arg)
@@ -84,10 +98,12 @@ static int plooptool_init(int argc, char **argv)
 	int i, f, ret;
 	off_t size_sec = 0;
 	char * endptr;
-	struct ploop_create_param param = {};
+	struct ploop_create_param param = {
+		.fstype		= "ext4",
+		.mode		= PLOOP_EXPANDED_MODE,
+		.fmt_version	= PLOOP_FMT_UNDEFINED,
+	};
 
-	param.mode = PLOOP_EXPANDED_MODE;
-	param.fmt_version = PLOOP_FMT_UNDEFINED;
 	while ((i = getopt(argc, argv, "s:b:B:f:t:v:")) != EOF) {
 		switch (i) {
 		case 's':
@@ -119,11 +135,14 @@ static int plooptool_init(int argc, char **argv)
 			param.mode = f;
 			break;
 		case 't':
-			if (!strcmp(optarg, "ext4") || !strcmp(optarg, "ext3")) {
+			if (!strcmp(optarg, "none"))
+				param.fstype = NULL;
+			else if (!strcmp(optarg, "ext4") ||
+					!strcmp(optarg, "ext3")) {
 				param.fstype = strdup(optarg);
 			} else {
-				fprintf(stderr, "Incorrect file system type specified: %s\n",
-						optarg);
+				fprintf(stderr, "Incorrect file system type "
+						"specified: %s\n", optarg);
 				return SYSEXIT_PARAM;
 			}
 			break;
@@ -470,6 +489,13 @@ static int plooptool_umount(int argc, char **argv)
 	}
 
 	if (umountopts.device != NULL) {
+		int len = strlen(umountopts.device);
+
+		/* if partition is provided, strip it */
+		if (strcmp(umountopts.device + len - 2, "p1") == 0 &&
+				isdigit(umountopts.device[len - 3]))
+			umountopts.device[len - 2] = '\0';
+
 		ret = ploop_umount(umountopts.device, NULL);
 	}else if (mnt != NULL) {
 		if (ploop_get_dev_by_mnt(mnt, device, sizeof(device))) {
@@ -796,7 +822,10 @@ static int plooptool_resize(int argc, char **argv)
 	int i, ret;
 	off_t new_size = 0; /* in sectors */
 	int max_balloon_size = 0; /* make balloon file of max possible size */
-	struct ploop_resize_param param = {.size = 0, .offline_resize = 1};
+	struct ploop_resize_param param = {
+		.size		= 0,
+		.offline_resize	= 1,
+	};
 	struct ploop_disk_images_data *di;
 
 	while ((i = getopt(argc, argv, "s:b")) != EOF) {
@@ -898,7 +927,7 @@ static int plooptool_convert(int argc, char **argv)
 
 static void usage_info(void)
 {
-	fprintf(stderr, "Usage: ploop info DiskDescriptor.xml\n");
+	fprintf(stderr, "Usage: ploop info [-s] DiskDescriptor.xml\n");
 }
 
 static void print_info(struct ploop_info *info)
@@ -917,21 +946,50 @@ static void print_info(struct ploop_info *info)
 
 static int plooptool_info(int argc, char **argv)
 {
-	int ret;
+	int ret, i;
+	int spec = 0;
 	struct ploop_info info = {};
 
-	/* skip the command itself (i.e. "info") */
-	argc -= 1;
-	argv += 1;
+	while ((i = getopt(argc, argv, "s")) != EOF) {
+		switch (i) {
+		case 's':
+			spec = 1;
+			break;
+		default:
+			usage_info();
+			return SYSEXIT_PARAM;
+		}
+	}
 
-	if (argc != 1) {
+	argc -= optind;
+	argv += optind;
+
+	if (argc != 1 || !is_xml_fname(argv[0])) {
 		usage_info();
 		return SYSEXIT_PARAM;
 	}
 
-	ret = ploop_get_info_by_descr(argv[0], &info);
-	if (ret == 0)
-		print_info(&info);
+	if (spec) {
+		struct ploop_disk_images_data *di;
+		struct ploop_spec spec = {};
+
+		ret = read_dd(&di, argv[0]);
+		if (ret)
+			return ret;
+
+		ret = ploop_get_spec(di, &spec);
+		if (ret == 0)
+			printf("size:\t\t%llu\nblocksize:\t%d\nfmt_version:\t%d\n",
+				(unsigned long long)spec.size,
+				spec.blocksize,
+				spec.fmt_version);
+
+		ploop_free_diskdescriptor(di);
+	} else {
+		ret = ploop_get_info_by_descr(argv[0], &info);
+		if (ret == 0)
+			print_info(&info);
+	}
 
 	return ret;
 }
@@ -948,7 +1006,6 @@ static int plooptool_list(int argc, char **argv)
 	char mnt[PATH_MAX] = "";
 	char dev[64];
 	DIR *dp;
-	struct stat st;
 	struct dirent *de;
 	char cookie[PLOOP_COOKIE_SIZE];
 	int all = 0;
@@ -985,13 +1042,13 @@ static int plooptool_list(int argc, char **argv)
 
 		snprintf(fname, sizeof(fname), "/sys/block/%s/pdelta/0/image",
 				de->d_name);
-		if (stat(fname, &st))
+		if (access(fname, F_OK))
 			continue;
 		if (read_line(fname, image, sizeof(image)))
 			continue;
 		snprintf(fname, sizeof(fname), "/sys/block/%s/pstate/cookie",
 				de->d_name);
-		if (stat(fname, &st) == 0) {
+		if (access(fname, F_OK) == 0) {
 			if (read_line(fname, cookie, sizeof(cookie)))
 				continue;
 		}
@@ -1058,6 +1115,21 @@ int main(int argc, char **argv)
 		return plooptool_info(argc, argv);
 	if (strcmp(cmd, "list") == 0)
 		return plooptool_list(argc, argv);
+	if (strcmp(cmd, "check") == 0)
+		return plooptool_check(argc, argv);
+	if (strcmp(cmd, "fsck") == 0) {
+		fprintf(stderr, "WARNING: ploop fsck command is obsoleted, "
+				"please use ploop check\n");
+		return plooptool_check(argc, argv);
+	}
+	if (strcmp(cmd, "grow") == 0)
+		return plooptool_grow(argc, argv);
+	if (strcmp(cmd, "merge") == 0)
+		return plooptool_merge(argc, argv);
+	if (strcmp(cmd, "stat") == 0)
+		return plooptool_stat(argc, argv);
+	if (strcmp(cmd, "copy") == 0)
+		return plooptool_copy(argc, argv);
 
 	if (cmd[0] != '-') {
 		char ** nargs;
